<?php
namespace WSCOMUN\RTSOA;
const unbounded = 'unbounded';

/**
 * Clase para consumir el servicio RTSOA va PHP. Consultar informacin adicional del servicio
 * @author belenguer_pab@externos.gva.es
 * @author pascual_dav@externos.gva.es
 *
 */
class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	*/
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace)
	{
		if (is_a($childData, 'DateTime'))
		{
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		}
		elseif (is_int($childData))
		{
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}


	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace)
	{
		switch ($basicType)
		{
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);
			break;

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		$fieldSet = isset($value);
		if (!$fieldSet)
		{
			if ($minOccurs > 0)
			{
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			}
			else
			{
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1)
		{
			$vChildData = array( $value );
		}
		else
		{
			if ($maxOccurs != 'unbounded')
			{
				if ($maxOccurs > sizeof($vChildData))
				{
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			}
			else
			{
				;
			}
		}

		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++)
		{
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet)
			{
				if (is_int($type) && $type != SOAP_ENC_OBJECT)
				{
					$basicType = $type;
					if ($basicType !== XSD_ANYTYPE)
					{
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					}
					else
					{
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append($childSOAP);

				}
				else
				{
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append($childSOAP);
				}
			}
			else
			{
				return false;
			}
		}
		return true;
	}



	public static function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	public static function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}


/**
 * Representa los datos del Libro Registral
 *
 */
class DATOS_LIBRO_REGISTRAL extends SoapObject
{
	const TIPO_LIBRO_REG_ENT 		= 1;
	const TIPO_LIBRO_REG_SAL_ACU 	= 2;
	const TIPO_LIBRO_REG_SAL 		= 3;

	private $_TIPO_LIBRO = null;
	private $_hasTIPO_LIBRO = false;
	private $_AMBITO_LIBRO_REGISTRAL = null;
	private $_hasAMBITO_LIBRO_REGISTRAL = false;
	private $_ANYO = null;
	private $_hasANYO = false;
	private $_CODIGO_OFICINA_REGISTRAL = null;
	private $_hasCODIGO_OFICINA_REGISTRAL = false;

	/**
	 * Fija el tipo de LIBRO. Es obligatorio establecerlo.
	 * @param integer $value [1: Registro de entrada | 2: Registro salida con acuse | 3: Registro de salida sin acuse]
	 */
	public function setTIPO_LIBRO($value)
	{
		$this->_TIPO_LIBRO = $value;
		$this->_hasTIPO_LIBRO = ($value !== null);
	}

	/**
	 * Devuelve si tiene fijado el tipo de libro o no
	 * @return boolean
	 */
	public function hasTIPO_LIBRO()
	{
		return $this->_hasTIPO_LIBRO;
	}

	/**
	 * Devuelve el tipo de LIBRO
	 * @return integer [1: Registro de entrada | 2: Registro salida con acuse | 3: Registro de salida sin acuse]
	 */
	public function getTIPO_LIBRO() {
		return $this->_TIPO_LIBRO;
	}


	/**
	 * Reservado para usos futuros. Se ignora
	 * @param mixed $value
	 */
	public function setAMBITO_LIBRO_REGISTRAL($value)
	{
		$this->_AMBITO_LIBRO_REGISTRAL = $value;
		$this->_hasAMBITO_LIBRO_REGISTRAL = ($value !== null);
	}
	public function hasAMBITO_LIBRO_REGISTRAL() {
		return $this->_hasAMBITO_LIBRO_REGISTRAL;
	}
	public function getAMBITO_LIBRO_REGISTRAL() {
		return $this->_AMBITO_LIBRO_REGISTRAL;
	}

	/**
	 * Establece el ao del registro
	 * @param integer $value Ao del registro
	 */
	public function setANYO($value)
	{
		$this->_ANYO = $value;
		$this->_hasANYO = ($value !== null);
	}
	public function hasANYO() {
		return $this->_hasANYO;
	}
	public function getANYO() {
		return $this->_ANYO;
	}


	/**
	 * Fiaj el cdigo de la oficina registral. Es un parmetro obligatorio.
	 * @param string $value Formato XXYYY donde XX es el organismo e YYY la unidad registral
	 */
	public function setCODIGO_OFICINA_REGISTRAL($value) {
		$this->_CODIGO_OFICINA_REGISTRAL = $value;
		$this->_hasCODIGO_OFICINA_REGISTRAL = ($value !== null);
	}
	public function hasCODIGO_OFICINA_REGISTRAL() {
		return $this->_hasCODIGO_OFICINA_REGISTRAL;
	}
	public function getCODIGO_OFICINA_REGISTRAL() {
		return $this->_CODIGO_OFICINA_REGISTRAL;
	}


	public static function fromSoap($vData) {
		$newItem = new DATOS_LIBRO_REGISTRAL();
		if (!isset($vData['TIPO_LIBRO'])) {
			throw new \Exception('El parametro TIPO_LIBRO es obligatorio');
		}
		if (isset($vData['TIPO_LIBRO'])) {
			$newItem->setTIPO_LIBRO($vData['TIPO_LIBRO']);
		}
		if (!isset($vData['AMBITO_LIBRO_REGISTRAL'])) {
			throw new \Exception('El parametro AMBITO_LIBRO_REGISTRAL es obligatorio');
		}
		if (isset($vData['AMBITO_LIBRO_REGISTRAL'])) {
			$newItem->setAMBITO_LIBRO_REGISTRAL($vData['AMBITO_LIBRO_REGISTRAL']);
		}
		if (!isset($vData['ANYO'])) {
			throw new \Exception('El parametro ANYO es obligatorio');
		}
		if (isset($vData['ANYO'])) {
			$newItem->setANYO($vData['ANYO']);
		}
		if (!isset($vData['CODIGO_OFICINA_REGISTRAL'])) {
			throw new \Exception('El parametro CODIGO_OFICINA_REGISTRAL es obligatorio');
		}
		if (isset($vData['CODIGO_OFICINA_REGISTRAL'])) {
			$newItem->setCODIGO_OFICINA_REGISTRAL($vData['CODIGO_OFICINA_REGISTRAL']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_TIPO_LIBRO, 'TIPO_LIBRO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_AMBITO_LIBRO_REGISTRAL, 'AMBITO_LIBRO_REGISTRAL', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_ANYO, 'ANYO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_CODIGO_OFICINA_REGISTRAL, 'CODIGO_OFICINA_REGISTRAL', 101, $namespace, 1, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasTIPO_LIBRO()) {
			$str .= '<TIPO_LIBRO>' . $this->getTIPO_LIBRO() . '</TIPO_LIBRO>';
		}
		if ($this->hasAMBITO_LIBRO_REGISTRAL()) {
			$str .= '<AMBITO_LIBRO_REGISTRAL>' . $this->getAMBITO_LIBRO_REGISTRAL() . '</AMBITO_LIBRO_REGISTRAL>';
		}
		if ($this->hasANYO()) {
			$str .= '<ANYO>' . $this->getANYO() . '</ANYO>';
		}
		if ($this->hasCODIGO_OFICINA_REGISTRAL()) {
			$str .= '<CODIGO_OFICINA_REGISTRAL>' . $this->getCODIGO_OFICINA_REGISTRAL() . '</CODIGO_OFICINA_REGISTRAL>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new DATOS_LIBRO_REGISTRAL();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'TIPO_LIBRO') {
				$newItem->setTIPO_LIBRO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'AMBITO_LIBRO_REGISTRAL') {
				$newItem->setAMBITO_LIBRO_REGISTRAL($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'ANYO') {
				$newItem->setANYO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CODIGO_OFICINA_REGISTRAL') {
				$newItem->setCODIGO_OFICINA_REGISTRAL($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}

class DATOS_UNIDAD extends SoapObject
{
	// name="CODIGO_UNIDAD" type="xs:string"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_CODIGO_UNIDAD = null;
	private $_hasCODIGO_UNIDAD = false;
	private $_TIPO_UNIDAD = null;
	private $_hasTIPO_UNIDAD = false;
	private $_DECODIFICACION_UNIDAD = null;
	private $_hasDECODIFICACION_UNIDAD = false;
	private $_ENVIO_BANDEJA = null;
	private $_hasENVIO_BANDEJA = false;
	private $_CODIGO_DIR3 = null;
	private $_hasCODIGO_DIR3 = false;


	public function setCODIGO_UNIDAD($value) {
		$this->_CODIGO_UNIDAD = $value;
		$this->_hasCODIGO_UNIDAD = ($value !== null);
	}
	public function hasCODIGO_UNIDAD() {
		return $this->_hasCODIGO_UNIDAD;
	}
	public function getCODIGO_UNIDAD() {
		return $this->_CODIGO_UNIDAD;
	}

	public function setTIPO_UNIDAD($value) {
		$this->_TIPO_UNIDAD = $value;
		$this->_hasTIPO_UNIDAD = ($value !== null);
	}
	public function hasTIPO_UNIDAD() {
		return $this->_hasTIPO_UNIDAD;
	}
	public function getTIPO_UNIDAD() {
		return $this->_TIPO_UNIDAD;
	}

	public function setDECODIFICACION_UNIDAD($value) {
		$this->_DECODIFICACION_UNIDAD = $value;
		$this->_hasDECODIFICACION_UNIDAD = ($value !== null);
	}
	public function hasDECODIFICACION_UNIDAD() {
		return $this->_hasDECODIFICACION_UNIDAD;
	}
	public function getDECODIFICACION_UNIDAD() {
		return $this->_DECODIFICACION_UNIDAD;
	}


	public function setENVIO_BANDEJA($value) {
		$this->_ENVIO_BANDEJA = $value;
		$this->_hasENVIO_BANDEJA = ($value !== null);
	}
	public function hasENVIO_BANDEJA() {
		return $this->_hasENVIO_BANDEJA;
	}
	public function getENVIO_BANDEJA() {
		return $this->_ENVIO_BANDEJA;
	}

	/**
	 * Establece el cdigo DIR3 (Directorio Comn de Unidades Orgnicas y Oficinas) del organismo
	 * @param string $value
	 */
	public function setCODIGO_DIR3($value) {
		$this->_CODIGO_DIR3 = $value;
		$this->_hasCODIGO_DIR3 = ($value !== null);
	}
	public function hasCODIGO_DIR3() {
		return $this->_hasCODIGO_DIR3;
	}
	public function getCODIGO_DIR3() {
		return $this->_CODIGO_DIR3;
	}


	public static function fromSoap($vData) {
		$newItem = new DATOS_UNIDAD();
		if (!isset($vData['CODIGO_UNIDAD'])) {
			throw new \Exception('El parametro CODIGO_UNIDAD es obligatorio');
		}
		if (isset($vData['CODIGO_UNIDAD'])) {
			$newItem->setCODIGO_UNIDAD($vData['CODIGO_UNIDAD']);
		}
		if (isset($vData['TIPO_UNIDAD'])) {
			$newItem->setTIPO_UNIDAD($vData['TIPO_UNIDAD']);
		}
		if (isset($vData['DECODIFICACION_UNIDAD'])) {
			$newItem->setDECODIFICACION_UNIDAD($vData['DECODIFICACION_UNIDAD']);
		}
		if (isset($vData['ENVIO_BANDEJA'])) {
			$newItem->setENVIO_BANDEJA($vData['ENVIO_BANDEJA']);
		}
		if (isset($vData['CODIGO_DIR3'])) {
			$newItem->setCODIGO_DIR3($vData['CODIGO_DIR3']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_CODIGO_UNIDAD, 'CODIGO_UNIDAD', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_TIPO_UNIDAD, 'TIPO_UNIDAD', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_DECODIFICACION_UNIDAD, 'DECODIFICACION_UNIDAD', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_ENVIO_BANDEJA, 'ENVIO_BANDEJA', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_CODIGO_DIR3, 'CODIGO_DIR3', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasCODIGO_UNIDAD()) {
			$str .= '<CODIGO_UNIDAD>' . $this->getCODIGO_UNIDAD() . '</CODIGO_UNIDAD>';
		}
		if ($this->hasTIPO_UNIDAD()) {
			$str .= '<TIPO_UNIDAD>' . $this->getTIPO_UNIDAD() . '</TIPO_UNIDAD>';
		}
		if ($this->hasDECODIFICACION_UNIDAD()) {
			$str .= '<DECODIFICACION_UNIDAD>' . $this->getDECODIFICACION_UNIDAD() . '</DECODIFICACION_UNIDAD>';
		}
		if ($this->hasENVIO_BANDEJA()) {
			$str .= '<ENVIO_BANDEJA>' . $this->getENVIO_BANDEJA() . '</ENVIO_BANDEJA>';
		}
		if ($this->hasCODIGO_DIR3()) {
			$str .= '<CODIGO_DIR3>' . $this->getCODIGO_DIR3() . '</CODIGO_DIR3>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new DATOS_UNIDAD();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'CODIGO_UNIDAD') {
				$newItem->setCODIGO_UNIDAD($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'TIPO_UNIDAD') {
				$newItem->setTIPO_UNIDAD($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'DECODIFICACION_UNIDAD') {
				$newItem->setDECODIFICACION_UNIDAD($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'ENVIO_BANDEJA') {
				$newItem->setENVIO_BANDEJA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CODIGO_DIR3') {
				$newItem->setCODIGO_DIR3($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}//Fin CLASE DATOS_UNIDAD

/**
 * Datos de la direccin del interesado.
 * Slo se tiene en cuenta la primera direccin, el resto se ignoran.
 * En el caso que se indique provincia ser obligatorio cumplimentar el municipio
 * @author belenguer_pab@externos.gva.es
 * @author pascual_dav@externos.gva.es
 *
 */
class DATOS_DIRECCION extends SoapObject
{
	private $_TIPO_DOMICILIO = null;
	private $_hasTIPO_DOMICILIO = false;
	private $_PAIS = null;
	private $_hasPAIS = false;
	private $_PROVINCIA = null;
	private $_hasPROVINCIA = false;
	private $_COMARCA = null;
	private $_hasCOMARCA = false;
	private $_MUNICIPIO = null;
	private $_hasMUNICIPIO = false;
	private $_POBLACION = null;
	private $_hasPOBLACION = false;
	private $_DIRECCION = null;
	private $_hasDIRECCION = false;
	private $_CODIGO_POSTAL = null;
	private $_hasCODIGO_POSTAL = false;

	public function setTIPO_DOMICILIO($value) {
		$this->_TIPO_DOMICILIO = $value;
		$this->_hasTIPO_DOMICILIO = ($value !== null);
	}
	public function hasTIPO_DOMICILIO() {
		return $this->_hasTIPO_DOMICILIO;
	}
	public function getTIPO_DOMICILIO() {
		return $this->_TIPO_DOMICILIO;
	}

	public function setPAIS($value) {
		$this->_PAIS = $value;
		$this->_hasPAIS = ($value !== null);
	}
	public function hasPAIS() {
		return $this->_hasPAIS;
	}
	public function getPAIS() {
		return $this->_PAIS;
	}

	/**
	 * Fija el cdigo de provincia
	 * @param string cdigo de provincias (Ver tablas comunes) Ej. '03', '12', '46'
	 */
	public function setPROVINCIA($value) {
		$this->_PROVINCIA = $value;
		$this->_hasPROVINCIA = ($value !== null);
	}
	public function hasPROVINCIA() {
		return $this->_hasPROVINCIA;
	}
	public function getPROVINCIA() {
		return $this->_PROVINCIA;
	}

	/**
	 * Fija el cdigo de comarca
	 * @param string cdigo de comarcas (Ver tablas comunes)
	 */
	public function setCOMARCA($value) {
		$this->_COMARCA = $value;
		$this->_hasCOMARCA = ($value !== null);
	}
	public function hasCOMARCA() {
		return $this->_hasCOMARCA;
	}
	public function getCOMARCA() {
		return $this->_COMARCA;
	}

	/**
	 * Fija el cdigo de municipio
	 * @param string cdigo de municipio (Ver tablas comunes)
	 */
	public function setMUNICIPIO($value) {
		$this->_MUNICIPIO = $value;
		$this->_hasMUNICIPIO = ($value !== null);
	}
	public function hasMUNICIPIO() {
		return $this->_hasMUNICIPIO;
	}
	public function getMUNICIPIO() {
		return $this->_MUNICIPIO;
	}

	/**
	 * Fija el cdigo de la poblacin
	 * @param string cdigo de poblacin  (Ver tablas comunes)
	 */
	public function setPOBLACION($value) {
		$this->_POBLACION = $value;
		$this->_hasPOBLACION = ($value !== null);
	}
	public function hasPOBLACION() {
		return $this->_hasPOBLACION;
	}
	public function getPOBLACION() {
		return $this->_POBLACION;
	}

	/**
	 * Fija la direccin del insteresado
	 * @param string $value
	 */
	public function setDIRECCION($value) {
		$this->_DIRECCION = $value;
		$this->_hasDIRECCION = ($value !== null);
	}
	public function hasDIRECCION() {
		return $this->_hasDIRECCION;
	}
	public function getDIRECCION() {
		return $this->_DIRECCION;
	}

	/**
	 * Fija el cdigo postal de la direccin
	 * @param string $value
	 */
	public function setCODIGO_POSTAL($value) {
		$this->_CODIGO_POSTAL = $value;
		$this->_hasCODIGO_POSTAL = ($value !== null);
	}
	public function hasCODIGO_POSTAL() {
		return $this->_hasCODIGO_POSTAL;
	}
	public function getCODIGO_POSTAL() {
		return $this->_CODIGO_POSTAL;
	}


	public static function fromSoap($vData) {
		$newItem = new DATOS_DIRECCION();
		if (isset($vData['TIPO_DOMICILIO'])) {
			$newItem->setTIPO_DOMICILIO($vData['TIPO_DOMICILIO']);
		}
		if (isset($vData['PAIS'])) {
			$newItem->setPAIS($vData['PAIS']);
		}
		if (isset($vData['PROVINCIA'])) {
			$newItem->setPROVINCIA($vData['PROVINCIA']);
		}
		if (isset($vData['COMARCA'])) {
			$newItem->setCOMARCA($vData['COMARCA']);
		}
		if (isset($vData['MUNICIPIO'])) {
			$newItem->setMUNICIPIO($vData['MUNICIPIO']);
		}
		if (isset($vData['POBLACION'])) {
			$newItem->setPOBLACION($vData['POBLACION']);
		}
		if (isset($vData['DIRECCION'])) {
			$newItem->setDIRECCION($vData['DIRECCION']);
		}
		if (isset($vData['CODIGO_POSTAL'])) {
			$newItem->setCODIGO_POSTAL($vData['CODIGO_POSTAL']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_TIPO_DOMICILIO, 'TIPO_DOMICILIO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_PAIS, 'PAIS', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_PROVINCIA, 'PROVINCIA', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_COMARCA, 'COMARCA', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_MUNICIPIO, 'MUNICIPIO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_POBLACION, 'POBLACION', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_DIRECCION, 'DIRECCION', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_CODIGO_POSTAL, 'CODIGO_POSTAL', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasTIPO_DOMICILIO()) {
			$str .= '<TIPO_DOMICILIO>' . $this->getTIPO_DOMICILIO() . '</TIPO_DOMICILIO>';
		}
		if ($this->hasPAIS()) {
			$str .= '<PAIS>' . $this->getPAIS() . '</PAIS>';
		}
		if ($this->hasPROVINCIA()) {
			$str .= '<PROVINCIA>' . $this->getPROVINCIA() . '</PROVINCIA>';
		}
		if ($this->hasCOMARCA()) {
			$str .= '<COMARCA>' . $this->getCOMARCA() . '</COMARCA>';
		}
		if ($this->hasMUNICIPIO()) {
			$str .= '<MUNICIPIO>' . $this->getMUNICIPIO() . '</MUNICIPIO>';
		}
		if ($this->hasPOBLACION()) {
			$str .= '<POBLACION>' . $this->getPOBLACION() . '</POBLACION>';
		}
		if ($this->hasDIRECCION()) {
			$str .= '<DIRECCION>' . $this->getDIRECCION() . '</DIRECCION>';
		}
		if ($this->hasCODIGO_POSTAL()) {
			$str .= '<CODIGO_POSTAL>' . $this->getCODIGO_POSTAL() . '</CODIGO_POSTAL>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new DATOS_DIRECCION();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'TIPO_DOMICILIO') {
				$newItem->setTIPO_DOMICILIO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'PAIS') {
				$newItem->setPAIS($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'PROVINCIA') {
				$newItem->setPROVINCIA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'COMARCA') {
				$newItem->setCOMARCA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'MUNICIPIO') {
				$newItem->setMUNICIPIO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'POBLACION') {
				$newItem->setPOBLACION($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'DIRECCION') {
				$newItem->setDIRECCION($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CODIGO_POSTAL') {
				$newItem->setCODIGO_POSTAL($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}//Fin clase DATOS_DIRECCION

/**
 * Clase para representar los datos del interesado
 * @author belenguer_pab@externos.gva.es
 * @author pascual_dav@externos.gva.es
 *
 */
class DATOS_INTERESADO extends SoapObject
{
	private $_NOMBRE = null;
	private $_hasNOMBRE = false;
	private $_APELLIDO1 = null;
	private $_hasAPELLIDO1 = false;
	private $_APELLIDO2 = null;
	private $_hasAPELLIDO2 = false;
	private $_TIPO_DOCUMENTO = null;
	private $_hasTIPO_DOCUMENTO = false;
	private $_TELEFONO = null;
	private $_hasTELEFONO = false;
	private $_NUMERO_IDENTIFICACION = null;
	private $_hasNUMERO_IDENTIFICACION = false;
	private $_FAX = null;
	private $_hasFAX = false;
	private $_TELEFONO_MOVIL = null;
	private $_hasTELEFONO_MOVIL = false;
	private $_DIRECCION_CORREO = null;
	private $_hasDIRECCION_CORREO = false;
	private $_DATOS_DIRECCION = null;
	private $_hasDATOS_DIRECCION = false;

	/**
	 * Nombre de pila del interesado (obligatorio)
	 * @param string $value
	 */
	public function setNOMBRE($value) {
		$this->_NOMBRE = $value;
		$this->_hasNOMBRE = ($value !== null);
	}
	public function hasNOMBRE() {
		return $this->_hasNOMBRE;
	}
	public function getNOMBRE() {
		return $this->_NOMBRE;
	}

	/**
	 * 1er apellido del interesado
	 * @param string $value
	 */
	public function setAPELLIDO1($value) {
		$this->_APELLIDO1 = $value;
		$this->_hasAPELLIDO1 = ($value !== null);
	}
	public function hasAPELLIDO1() {
		return $this->_hasAPELLIDO1;
	}
	public function getAPELLIDO1() {
		return $this->_APELLIDO1;
	}

	/**
	 * 2o apellido del interesado
	 * @param string $value
	 */
	public function setAPELLIDO2($value) {
		$this->_APELLIDO2 = $value;
		$this->_hasAPELLIDO2 = ($value !== null);
	}
	public function hasAPELLIDO2() {
		return $this->_hasAPELLIDO2;
	}
	public function getAPELLIDO2() {
		return $this->_APELLIDO2;
	}

	/**
	 * Tipo de documento de identificacin de interesado (DNI, NIR....)
	 * @param string $value [1: DNI, NIF, CIF / 2: Otros / etc. (Codificado en la tabla DB_TIPOS_DOCUMENTO de MASTIN)]
	 */
	public function setTIPO_DOCUMENTO($value) {
		$this->_TIPO_DOCUMENTO = $value;
		$this->_hasTIPO_DOCUMENTO = ($value !== null);
	}
	public function hasTIPO_DOCUMENTO() {
		return $this->_hasTIPO_DOCUMENTO;
	}
	public function getTIPO_DOCUMENTO() {
		return $this->_TIPO_DOCUMENTO;
	}
	/**
	 Nmero del documento del tipo establecido (el nmero de DNI, NIE, etc...)
	 * @param string $value
	 */
	public function setNUMERO_IDENTIFICACION($value) {
		$this->_NUMERO_IDENTIFICACION = $value;
		$this->_hasNUMERO_IDENTIFICACION = ($value !== null);
	}
	public function hasNUMERO_IDENTIFICACION() {
		return $this->_hasNUMERO_IDENTIFICACION;
	}
	public function getNUMERO_IDENTIFICACION() {
		return $this->_NUMERO_IDENTIFICACION;
	}

	public function setTELEFONO($value) {
		$this->_TELEFONO = $value;
		$this->_hasTELEFONO = ($value !== null);
	}
	public function hasTELEFONO() {
		return $this->_hasTELEFONO;
	}
	public function getTELEFONO() {
		return $this->_TELEFONO;
	}

	public function setTELEFONO_MOVIL($value) {
		$this->_TELEFONO_MOVIL = $value;
		$this->_hasTELEFONO_MOVIL = ($value !== null);
	}
	public function hasTELEFONO_MOVIL() {
		return $this->_hasTELEFONO_MOVIL;
	}
	public function getTELEFONO_MOVIL() {
		return $this->_TELEFONO_MOVIL;
	}

	public function setFAX($value) {
		$this->_FAX = $value;
		$this->_hasFAX = ($value !== null);
	}
	public function hasFAX() {
		return $this->_hasFAX;
	}
	public function getFAX() {
		return $this->_FAX;
	}

	/**
	 * Direccin de correo electrnico  para el envo
	 * @param string $value
	 */
	public function setDIRECCION_CORREO($value) {
		$this->_DIRECCION_CORREO = $value;
		$this->_hasDIRECCION_CORREO = ($value !== null);
	}
	public function hasDIRECCION_CORREO() {
		return $this->_hasDIRECCION_CORREO;
	}
	public function getDIRECCION_CORREO() {
		return $this->_DIRECCION_CORREO;
	}

	public function setDATOS_DIRECCION($value) {
		$this->_DATOS_DIRECCION = $value;
		$this->_hasDATOS_DIRECCION = ($value !== null);
	}
	public function hasDATOS_DIRECCION() {
		return $this->_hasDATOS_DIRECCION;
	}
	public function getDATOS_DIRECCION() {
		return $this->_DATOS_DIRECCION;
	}


	public static function fromSoap($vData) {
		$newItem = new DATOS_INTERESADO();
		if (!isset($vData['NOMBRE'])) {
			throw new \Exception('El parametro NOMBRE es obligatorio');
		}
		if (isset($vData['NOMBRE'])) {
			$newItem->setNOMBRE($vData['NOMBRE']);
		}
		if (isset($vData['APELLIDO1'])) {
			$newItem->setAPELLIDO1($vData['APELLIDO1']);
		}
		if (isset($vData['APELLIDO2'])) {
			$newItem->setAPELLIDO2($vData['APELLIDO2']);
		}
		if (!isset($vData['TIPO_DOCUMENTO'])) {
			throw new \Exception('El parametro TIPO_DOCUMENTO es obligatorio');
		}
		if (isset($vData['TIPO_DOCUMENTO'])) {
			$newItem->setTIPO_DOCUMENTO($vData['TIPO_DOCUMENTO']);
		}
		if (!isset($vData['NUMERO_IDENTIFICACION'])) {
			throw new \Exception('El parametro NUMERO_IDENTIFICACION es obligatorio');
		}
		if (isset($vData['NUMERO_IDENTIFICACION'])) {
			$newItem->setNUMERO_IDENTIFICACION($vData['NUMERO_IDENTIFICACION']);
		}
		if (isset($vData['TELEFONO'])) {
			$newItem->setTELEFONO($vData['TELEFONO']);
		}
		if (isset($vData['TELEFONO_MOVIL'])) {
			$newItem->setTELEFONO_MOVIL($vData['TELEFONO_MOVIL']);
		}
		if (isset($vData['FAX'])) {
			$newItem->setFAX($vData['FAX']);
		}
		if (isset($vData['DIRECCION_CORREO'])) {
			$newItem->setDIRECCION_CORREO($vData['DIRECCION_CORREO']);
		}
		if (isset($vData['DATOS_DIRECCION'])) {
			$newClass = DATOS_DIRECCION::fromSoap($vData['DATOS_DIRECCION']);
			$newItem->setDATOS_DIRECCION($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_NOMBRE, 'NOMBRE', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_APELLIDO1, 'APELLIDO1', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_APELLIDO2, 'APELLIDO2', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_TIPO_DOCUMENTO, 'TIPO_DOCUMENTO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_NUMERO_IDENTIFICACION, 'NUMERO_IDENTIFICACION', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_TELEFONO, 'TELEFONO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_TELEFONO_MOVIL, 'TELEFONO_MOVIL', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_FAX, 'FAX', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_DIRECCION_CORREO, 'DIRECCION_CORREO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_DATOS_DIRECCION, 'DATOS_DIRECCION', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasNOMBRE()) {
			$str .= '<NOMBRE>' . $this->getNOMBRE() . '</NOMBRE>';
		}
		if ($this->hasAPELLIDO1()) {
			$str .= '<APELLIDO1>' . $this->getAPELLIDO1() . '</APELLIDO1>';
		}
		if ($this->hasAPELLIDO2()) {
			$str .= '<APELLIDO2>' . $this->getAPELLIDO2() . '</APELLIDO2>';
		}
		if ($this->hasTIPO_DOCUMENTO()) {
			$str .= '<TIPO_DOCUMENTO>' . $this->getTIPO_DOCUMENTO() . '</TIPO_DOCUMENTO>';
		}
		if ($this->hasNUMERO_IDENTIFICACION()) {
			$str .= '<NUMERO_IDENTIFICACION>' . $this->getNUMERO_IDENTIFICACION() . '</NUMERO_IDENTIFICACION>';
		}
		if ($this->hasTELEFONO()) {
			$str .= '<TELEFONO>' . $this->getTELEFONO() . '</TELEFONO>';
		}
		if ($this->hasTELEFONO_MOVIL()) {
			$str .= '<TELEFONO_MOVIL>' . $this->getTELEFONO_MOVIL() . '</TELEFONO_MOVIL>';
		}
		if ($this->hasFAX()) {
			$str .= '<FAX>' . $this->getFAX() . '</FAX>';
		}
		if ($this->hasDIRECCION_CORREO()) {
			$str .= '<DIRECCION_CORREO>' . $this->getDIRECCION_CORREO() . '</DIRECCION_CORREO>';
		}
		if ($this->hasDATOS_DIRECCION()) {
			$str .= '<DATOS_DIRECCION>' . $this->getDATOS_DIRECCION()->generateString() . '</DATOS_DIRECCION>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new DATOS_INTERESADO();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'NOMBRE') {
				$newItem->setNOMBRE($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'APELLIDO1') {
				$newItem->setAPELLIDO1($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'APELLIDO2') {
				$newItem->setAPELLIDO2($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'TIPO_DOCUMENTO') {
				$newItem->setTIPO_DOCUMENTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'NUMERO_IDENTIFICACION') {
				$newItem->setNUMERO_IDENTIFICACION($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'TELEFONO') {
				$newItem->setTELEFONO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'TELEFONO_MOVIL') {
				$newItem->setTELEFONO_MOVIL($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FAX') {
				$newItem->setFAX($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'DIRECCION_CORREO') {
				$newItem->setDIRECCION_CORREO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'DATOS_DIRECCION') {
				$newClass = DATOS_DIRECCION::fromDOM($nodeXML);
				$newItem->setDATOS_DIRECCION($newClass);
			}

		}
		return $newItem;
	}
}//Fin Clase DATOS_INTERESADO

/**
 * Representa otros datos del interesado: DESCRIPCION DEL ASUNTO, OBSERVACIONES (futuro uso, se ignora)...
 * @author belenguer_pab@externos.gva.es
 * @author pascual_dav@externos.gva.es
 *
 */
class OTROS_DATOS extends SoapObject
{
	private $_CODIGO_ASUNTO = null;
	private $_hasCODIGO_ASUNTO = false;
	private $_DESCRIPCION_ASUNTO = null;
	private $_hasDESCRIPCION_ASUNTO = false;
	private $_OBSERVACIONES = null;
	private $_hasOBSERVACIONES = false;
	private $_REFERENCIA_EXTERNA = null;
	private $_hasREFERENCIA_EXTERNA = false;
	private $_CODIGO_TIPO_TRANSPORTE = null;
	private $_hasCODIGO_TIPO_TRANSPORTE = false;
	private $_NUMERO_TRANSPORTE = null;
	private $_hasNUMERO_TRANSPORTE = false;
	private $_FECHA_FIN_PLAZO = null;
	private $_hasFECHA_FIN_PLAZO = false;
	private $_FECHA_ACUSE = null;
	private $_hasFECHA_ACUSE = false;
	private $_CODIGO_SIA = null;
	private $_hasCODIGO_SIA = false;


	public function setCODIGO_ASUNTO($value) {
		$this->_CODIGO_ASUNTO = $value;
		$this->_hasCODIGO_ASUNTO = ($value !== null);
	}
	public function hasCODIGO_ASUNTO() {
		return $this->_hasCODIGO_ASUNTO;
	}
	public function getCODIGO_ASUNTO() {
		return $this->_CODIGO_ASUNTO;
	}

	public function setDESCRIPCION_ASUNTO($value) {
		$this->_DESCRIPCION_ASUNTO = $value;
		$this->_hasDESCRIPCION_ASUNTO = ($value !== null);
	}
	public function hasDESCRIPCION_ASUNTO() {
		return $this->_hasDESCRIPCION_ASUNTO;
	}
	public function getDESCRIPCION_ASUNTO() {
		return $this->_DESCRIPCION_ASUNTO;
	}

	public function setOBSERVACIONES($value) {
		$this->_OBSERVACIONES = $value;
		$this->_hasOBSERVACIONES = ($value !== null);
	}
	public function hasOBSERVACIONES() {
		return $this->_hasOBSERVACIONES;
	}
	public function getOBSERVACIONES() {
		return $this->_OBSERVACIONES;
	}

	public function setREFERENCIA_EXTERNA($value) {
		$this->_REFERENCIA_EXTERNA = $value;
		$this->_hasREFERENCIA_EXTERNA = ($value !== null);
	}
	public function hasREFERENCIA_EXTERNA() {
		return $this->_hasREFERENCIA_EXTERNA;
	}
	public function getREFERENCIA_EXTERNA() {
		return $this->_REFERENCIA_EXTERNA;
	}

	public function setCODIGO_TIPO_TRANSPORTE($value) {
		$this->_CODIGO_TIPO_TRANSPORTE = $value;
		$this->_hasCODIGO_TIPO_TRANSPORTE = ($value !== null);
	}
	public function hasCODIGO_TIPO_TRANSPORTE() {
		return $this->_hasCODIGO_TIPO_TRANSPORTE;
	}
	public function getCODIGO_TIPO_TRANSPORTE() {
		return $this->_CODIGO_TIPO_TRANSPORTE;
	}

	public function setNUMERO_TRANSPORTE($value) {
		$this->_NUMERO_TRANSPORTE = $value;
		$this->_hasNUMERO_TRANSPORTE = ($value !== null);
	}
	public function hasNUMERO_TRANSPORTE() {
		return $this->_hasNUMERO_TRANSPORTE;
	}
	public function getNUMERO_TRANSPORTE() {
		return $this->_NUMERO_TRANSPORTE;
	}

	public function setFECHA_FIN_PLAZO($value) {
		$this->_FECHA_FIN_PLAZO = $value;
		$this->_hasFECHA_FIN_PLAZO = ($value !== null);
	}
	public function hasFECHA_FIN_PLAZO() {
		return $this->_hasFECHA_FIN_PLAZO;
	}
	public function getFECHA_FIN_PLAZO() {
		return $this->_FECHA_FIN_PLAZO;
	}

	public function setFECHA_ACUSE($value) {
		$this->_FECHA_ACUSE = $value;
		$this->_hasFECHA_ACUSE = ($value !== null);
	}
	public function hasFECHA_ACUSE() {
		return $this->_hasFECHA_ACUSE;
	}
	public function getFECHA_ACUSE() {
		return $this->_FECHA_ACUSE;
	}

	/**
	 * Cdigo SIA (SISTEMA DE INFORMACIN ADMINISTRATIVA) que identifica el procedimiento administrativo
	 * @param string $value
	 */
	public function setCODIGO_SIA($value) {
		$this->_CODIGO_SIA = $value;
		$this->_hasCODIGO_SIA = ($value !== null);
	}
	public function hasCODIGO_SIA() {
		return $this->_hasCODIGO_SIA;
	}
	public function getCODIGO_SIA() {
		return $this->_CODIGO_SIA;
	}


	public static function fromSoap($vData) {
		$newItem = new OTROS_DATOS();
		if (isset($vData['CODIGO_ASUNTO'])) {
			$newItem->setCODIGO_ASUNTO($vData['CODIGO_ASUNTO']);
		}
		if (!isset($vData['DESCRIPCION_ASUNTO'])) {
			throw new \Exception('El parametro DESCRIPCION_ASUNTO es obligatorio');
		}
		if (isset($vData['DESCRIPCION_ASUNTO'])) {
			$newItem->setDESCRIPCION_ASUNTO($vData['DESCRIPCION_ASUNTO']);
		}
		if (isset($vData['OBSERVACIONES'])) {
			$newItem->setOBSERVACIONES($vData['OBSERVACIONES']);
		}
		if (isset($vData['REFERENCIA_EXTERNA'])) {
			$newItem->setREFERENCIA_EXTERNA($vData['REFERENCIA_EXTERNA']);
		}
		if (isset($vData['CODIGO_TIPO_TRANSPORTE'])) {
			$newItem->setCODIGO_TIPO_TRANSPORTE($vData['CODIGO_TIPO_TRANSPORTE']);
		}
		if (isset($vData['NUMERO_TRANSPORTE'])) {
			$newItem->setNUMERO_TRANSPORTE($vData['NUMERO_TRANSPORTE']);
		}
		if (isset($vData['FECHA_FIN_PLAZO'])) {
			$newItem->setFECHA_FIN_PLAZO($vData['FECHA_FIN_PLAZO']);
		}
		if (isset($vData['FECHA_ACUSE'])) {
			$newItem->setFECHA_ACUSE($vData['FECHA_ACUSE']);
		}
		if (isset($vData['CODIGO_SIA'])) {
			$newItem->setCODIGO_SIA($vData['CODIGO_SIA']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_CODIGO_ASUNTO, 'CODIGO_ASUNTO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_DESCRIPCION_ASUNTO, 'DESCRIPCION_ASUNTO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_OBSERVACIONES, 'OBSERVACIONES', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_REFERENCIA_EXTERNA, 'REFERENCIA_EXTERNA', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_CODIGO_TIPO_TRANSPORTE, 'CODIGO_TIPO_TRANSPORTE', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_NUMERO_TRANSPORTE, 'NUMERO_TRANSPORTE', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_FECHA_FIN_PLAZO, 'FECHA_FIN_PLAZO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_FECHA_ACUSE, 'FECHA_ACUSE', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_CODIGO_SIA, 'CODIGO_SIA', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasCODIGO_ASUNTO()) {
			$str .= '<CODIGO_ASUNTO>' . $this->getCODIGO_ASUNTO() . '</CODIGO_ASUNTO>';
		}
		if ($this->hasDESCRIPCION_ASUNTO()) {
			$str .= '<DESCRIPCION_ASUNTO>' . $this->getDESCRIPCION_ASUNTO() . '</DESCRIPCION_ASUNTO>';
		}
		if ($this->hasOBSERVACIONES()) {
			$str .= '<OBSERVACIONES>' . $this->getOBSERVACIONES() . '</OBSERVACIONES>';
		}
		if ($this->hasREFERENCIA_EXTERNA()) {
			$str .= '<REFERENCIA_EXTERNA>' . $this->getREFERENCIA_EXTERNA() . '</REFERENCIA_EXTERNA>';
		}
		if ($this->hasCODIGO_TIPO_TRANSPORTE()) {
			$str .= '<CODIGO_TIPO_TRANSPORTE>' . $this->getCODIGO_TIPO_TRANSPORTE() . '</CODIGO_TIPO_TRANSPORTE>';
		}
		if ($this->hasNUMERO_TRANSPORTE()) {
			$str .= '<NUMERO_TRANSPORTE>' . $this->getNUMERO_TRANSPORTE() . '</NUMERO_TRANSPORTE>';
		}
		if ($this->hasFECHA_FIN_PLAZO()) {
			$str .= '<FECHA_FIN_PLAZO>' . $this->getFECHA_FIN_PLAZO() . '</FECHA_FIN_PLAZO>';
		}
		if ($this->hasFECHA_ACUSE()) {
			$str .= '<FECHA_ACUSE>' . $this->getFECHA_ACUSE() . '</FECHA_ACUSE>';
		}
		if ($this->hasCODIGO_SIA()) {
			$str .= '<CODIGO_SIA>' . $this->getCODIGO_SIA() . '</CODIGO_SIA>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new OTROS_DATOS();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'CODIGO_ASUNTO') {
				$newItem->setCODIGO_ASUNTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'DESCRIPCION_ASUNTO') {
				$newItem->setDESCRIPCION_ASUNTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'OBSERVACIONES') {
				$newItem->setOBSERVACIONES($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'REFERENCIA_EXTERNA') {
				$newItem->setREFERENCIA_EXTERNA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CODIGO_TIPO_TRANSPORTE') {
				$newItem->setCODIGO_TIPO_TRANSPORTE($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'NUMERO_TRANSPORTE') {
				$newItem->setNUMERO_TRANSPORTE($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FECHA_FIN_PLAZO') {
				$newItem->setFECHA_FIN_PLAZO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FECHA_ACUSE') {
				$newItem->setFECHA_ACUSE($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CODIGO_SIA') {
				$newItem->setCODIGO_SIA($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}

/**
 * Representa los datos del expediente
 * @author belenguer_pab@externos.gva.es
 * @author pascual_dav@externos.gva.es
 *
 */
class DATOS_EXPEDIENTES extends SoapObject
{
	private $_TIPO = null;
	private $_hasTIPO = false;
	private $_TIPOACTOR = null;
	private $_hasTIPOACTOR = false;
	private $_VALORACTOR = null;
	private $_hasVALORACTOR = false;
	private $_A_CODIGO_EXPEDIENTE = null;
	private $_hasA_CODIGO_EXPEDIENTE = false;
	private $_A_CODIGO_TAREA = null;
	private $_hasA_CODIGO_TAREA = false;
	private $_B_CODIGO_PROCED = null;
	private $_hasB_CODIGO_PROCED = false;
	private $_N_CODIGO_PROCED = null;
	private $_hasN_CODIGO_PROCED = false;
	private $_N_ASUNTO = null;
	private $_hasN_ASUNTO = false;
	private $_N_ANYO = null;
	private $_hasN_ANYO = false;

	public function setTIPO($value)
	{
		$this->_TIPO = $value;
		$this->_hasTIPO = ($value !== null);
	}
	public function hasTIPO() {
		return $this->_hasTIPO;
	}
	public function getTIPO() {
		return $this->_TIPO;
	}

	public function setTIPOACTOR($value) {
		$this->_TIPOACTOR = $value;
		$this->_hasTIPOACTOR = ($value !== null);
	}
	public function hasTIPOACTOR() {
		return $this->_hasTIPOACTOR;
	}
	public function getTIPOACTOR() {
		return $this->_TIPOACTOR;
	}

	public function setVALORACTOR($value) {
		$this->_VALORACTOR = $value;
		$this->_hasVALORACTOR = ($value !== null);
	}
	public function hasVALORACTOR() {
		return $this->_hasVALORACTOR;
	}
	public function getVALORACTOR() {
		return $this->_VALORACTOR;
	}


	public function setA_CODIGO_EXPEDIENTE($value) {
		$this->_A_CODIGO_EXPEDIENTE = $value;
		$this->_hasA_CODIGO_EXPEDIENTE = ($value !== null);
	}
	public function hasA_CODIGO_EXPEDIENTE() {
		return $this->_hasA_CODIGO_EXPEDIENTE;
	}
	public function getA_CODIGO_EXPEDIENTE() {
		return $this->_A_CODIGO_EXPEDIENTE;
	}


	public function setA_CODIGO_TAREA($value) {
		$this->_A_CODIGO_TAREA = $value;
		$this->_hasA_CODIGO_TAREA = ($value !== null);
	}
	public function hasA_CODIGO_TAREA() {
		return $this->_hasA_CODIGO_TAREA;
	}
	public function getA_CODIGO_TAREA() {
		return $this->_A_CODIGO_TAREA;
	}

	public function setB_CODIGO_PROCED($value) {
		$this->_B_CODIGO_PROCED = $value;
		$this->_hasB_CODIGO_PROCED = ($value !== null);
	}
	public function hasB_CODIGO_PROCED() {
		return $this->_hasB_CODIGO_PROCED;
	}
	public function getB_CODIGO_PROCED() {
		return $this->_B_CODIGO_PROCED;
	}

	public function setN_CODIGO_PROCED($value) {
		$this->_N_CODIGO_PROCED = $value;
		$this->_hasN_CODIGO_PROCED = ($value !== null);
	}
	public function hasN_CODIGO_PROCED() {
		return $this->_hasN_CODIGO_PROCED;
	}
	public function getN_CODIGO_PROCED() {
		return $this->_N_CODIGO_PROCED;
	}

	public function setN_ASUNTO($value) {
		$this->_N_ASUNTO = $value;
		$this->_hasN_ASUNTO = ($value !== null);
	}
	public function hasN_ASUNTO() {
		return $this->_hasN_ASUNTO;
	}
	public function getN_ASUNTO() {
		return $this->_N_ASUNTO;
	}

	public function setN_ANYO($value) {
		$this->_N_ANYO = $value;
		$this->_hasN_ANYO = ($value !== null);
	}
	public function hasN_ANYO() {
		return $this->_hasN_ANYO;
	}
	public function getN_ANYO() {
		return $this->_N_ANYO;
	}


	public static function fromSoap($vData) {
		$newItem = new DATOS_EXPEDIENTES();
		if (isset($vData['TIPO'])) {
			$newItem->setTIPO($vData['TIPO']);
		}
		if (isset($vData['TIPOACTOR'])) {
			$newItem->setTIPOACTOR($vData['TIPOACTOR']);
		}
		if (isset($vData['VALORACTOR'])) {
			$newItem->setVALORACTOR($vData['VALORACTOR']);
		}
		if (isset($vData['A_CODIGO_EXPEDIENTE'])) {
			$newItem->setA_CODIGO_EXPEDIENTE($vData['A_CODIGO_EXPEDIENTE']);
		}
		if (isset($vData['A_CODIGO_TAREA'])) {
			$newItem->setA_CODIGO_TAREA($vData['A_CODIGO_TAREA']);
		}
		if (isset($vData['B_CODIGO_PROCED'])) {
			$newItem->setB_CODIGO_PROCED($vData['B_CODIGO_PROCED']);
		}
		if (isset($vData['N_CODIGO_PROCED'])) {
			$newItem->setN_CODIGO_PROCED($vData['N_CODIGO_PROCED']);
		}
		if (isset($vData['N_ASUNTO'])) {
			$newItem->setN_ASUNTO($vData['N_ASUNTO']);
		}
		if (isset($vData['N_ANYO'])) {
			$newItem->setN_ANYO($vData['N_ANYO']);
		}

		return $newItem;
	}

	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_TIPO, 'TIPO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_TIPOACTOR, 'TIPOACTOR', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_VALORACTOR, 'VALORACTOR', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_A_CODIGO_EXPEDIENTE, 'A_CODIGO_EXPEDIENTE', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_A_CODIGO_TAREA, 'A_CODIGO_TAREA', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_B_CODIGO_PROCED, 'B_CODIGO_PROCED', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_N_CODIGO_PROCED, 'N_CODIGO_PROCED', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_N_ASUNTO, 'N_ASUNTO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_N_ANYO, 'N_ANYO', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}

	public function generateString() {
		$str = '';

		if ($this->hasTIPO()) {
			$str .= '<TIPO>' . $this->getTIPO() . '</TIPO>';
		}
		if ($this->hasTIPOACTOR()) {
			$str .= '<TIPOACTOR>' . $this->getTIPOACTOR() . '</TIPOACTOR>';
		}
		if ($this->hasVALORACTOR()) {
			$str .= '<VALORACTOR>' . $this->getVALORACTOR() . '</VALORACTOR>';
		}
		if ($this->hasA_CODIGO_EXPEDIENTE()) {
			$str .= '<A_CODIGO_EXPEDIENTE>' . $this->getA_CODIGO_EXPEDIENTE() . '</A_CODIGO_EXPEDIENTE>';
		}
		if ($this->hasA_CODIGO_TAREA()) {
			$str .= '<A_CODIGO_TAREA>' . $this->getA_CODIGO_TAREA() . '</A_CODIGO_TAREA>';
		}
		if ($this->hasB_CODIGO_PROCED()) {
			$str .= '<B_CODIGO_PROCED>' . $this->getB_CODIGO_PROCED() . '</B_CODIGO_PROCED>';
		}
		if ($this->hasN_CODIGO_PROCED()) {
			$str .= '<N_CODIGO_PROCED>' . $this->getN_CODIGO_PROCED() . '</N_CODIGO_PROCED>';
		}
		if ($this->hasN_ASUNTO()) {
			$str .= '<N_ASUNTO>' . $this->getN_ASUNTO() . '</N_ASUNTO>';
		}
		if ($this->hasN_ANYO()) {
			$str .= '<N_ANYO>' . $this->getN_ANYO() . '</N_ANYO>';
		}

		return $str;
	}

	public static function fromDOM($nodeParent) {
		$newItem = new DATOS_EXPEDIENTES();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'TIPO') {
				$newItem->setTIPO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'TIPOACTOR') {
				$newItem->setTIPOACTOR($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'VALORACTOR') {
				$newItem->setVALORACTOR($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'A_CODIGO_EXPEDIENTE') {
				$newItem->setA_CODIGO_EXPEDIENTE($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'A_CODIGO_TAREA') {
				$newItem->setA_CODIGO_TAREA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'B_CODIGO_PROCED') {
				$newItem->setB_CODIGO_PROCED($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'N_CODIGO_PROCED') {
				$newItem->setN_CODIGO_PROCED($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'N_ASUNTO') {
				$newItem->setN_ASUNTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'N_ANYO') {
				$newItem->setN_ANYO($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}//Fin DATOS_EXPEDIENTES


/**
 * Representa la firma del Documento
 * @author belenguer_pab@externos.gva.es
 * @author pascual_dav@externos.gva.es
 */
class FIRMA_DOCUMENTO extends SoapObject
{
	private $_ENTIDAD_CERTIFICADORA = null;
	private $_hasENTIDAD_CERTIFICADORA = false;
	private $_FORMATO_FIRMA = null;
	private $_hasFORMATO_FIRMA = false;
	private $_VALOR_FIRMA = null;
	private $_hasVALOR_FIRMA = false;

	public function setENTIDAD_CERTIFICADORA($value)
	{
		$this->_ENTIDAD_CERTIFICADORA = $value;
		$this->_hasENTIDAD_CERTIFICADORA = ($value !== null);
	}
	public function hasENTIDAD_CERTIFICADORA() {
		return $this->_hasENTIDAD_CERTIFICADORA;
	}
	public function getENTIDAD_CERTIFICADORA() {
		return $this->_ENTIDAD_CERTIFICADORA;
	}

	public function setFORMATO_FIRMA($value) {
		$this->_FORMATO_FIRMA = $value;
		$this->_hasFORMATO_FIRMA = ($value !== null);
	}
	public function hasFORMATO_FIRMA() {
		return $this->_hasFORMATO_FIRMA;
	}
	public function getFORMATO_FIRMA() {
		return $this->_FORMATO_FIRMA;
	}

	public function setVALOR_FIRMA($value) {
		$this->_VALOR_FIRMA = $value;
		$this->_hasVALOR_FIRMA = ($value !== null);
	}
	public function hasVALOR_FIRMA() {
		return $this->_hasVALOR_FIRMA;
	}
	public function getVALOR_FIRMA() {
		return $this->_VALOR_FIRMA;
	}


	public static function fromSoap($vData) {
		$newItem = new FIRMA_DOCUMENTO();
		if (!isset($vData['ENTIDAD_CERTIFICADORA'])) {
			throw new \Exception('El parametro ENTIDAD_CERTIFICADORA es obligatorio');
		}
		if (isset($vData['ENTIDAD_CERTIFICADORA'])) {
			$newItem->setENTIDAD_CERTIFICADORA($vData['ENTIDAD_CERTIFICADORA']);
		}
		if (!isset($vData['FORMATO_FIRMA'])) {
			throw new \Exception('El parametro FORMATO_FIRMA es obligatorio');
		}
		if (isset($vData['FORMATO_FIRMA'])) {
			$newItem->setFORMATO_FIRMA($vData['FORMATO_FIRMA']);
		}
		if (isset($vData['VALOR_FIRMA'])) {
			$newItem->setVALOR_FIRMA($vData['VALOR_FIRMA']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_ENTIDAD_CERTIFICADORA, 'ENTIDAD_CERTIFICADORA', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_FORMATO_FIRMA, 'FORMATO_FIRMA', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_VALOR_FIRMA, 'VALOR_FIRMA', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasENTIDAD_CERTIFICADORA()) {
			$str .= '<ENTIDAD_CERTIFICADORA>' . $this->getENTIDAD_CERTIFICADORA() . '</ENTIDAD_CERTIFICADORA>';
		}
		if ($this->hasFORMATO_FIRMA()) {
			$str .= '<FORMATO_FIRMA>' . $this->getFORMATO_FIRMA() . '</FORMATO_FIRMA>';
		}
		if ($this->hasVALOR_FIRMA()) {
			$str .= '<VALOR_FIRMA>' . $this->getVALOR_FIRMA() . '</VALOR_FIRMA>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new FIRMA_DOCUMENTO();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'ENTIDAD_CERTIFICADORA') {
				$newItem->setENTIDAD_CERTIFICADORA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FORMATO_FIRMA') {
				$newItem->setFORMATO_FIRMA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'VALOR_FIRMA') {
				$newItem->setVALOR_FIRMA($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}//Fin clase FIRMA_DOCUMENTO

/**
 * Representa los documentos anexos
 * @author p
 *
 */
class DOCUMENTOS_ANEXOS extends SoapObject
{
	private $_NOMBRE_FICHERO = null;
	private $_hasNOMBRE_FICHERO = false;
	private $_CODIGO_DOCUMENTO = null;
	private $_hasCODIGO_DOCUMENTO = false;
	private $_DESCRIPCION_DOCUMENTO = null;
	private $_hasDESCRIPCION_DOCUMENTO = false;
	private $_TIPO_DOCUMENTO = null;
	private $_hasTIPO_DOCUMENTO = false;
	private $_IDENTIFICADOR_FICHERO = null;
	private $_hasIDENTIFICADOR_FICHERO = false;
	private $_HASH_DOCUMENTO = null;
	private $_hasHASH_DOCUMENTO = false;
	private $_IDENTIFICADOR_DOCUMENTO_FIRMADO = null;
	private $_hasIDENTIFICADOR_DOCUMENTO_FIRMADO = false;
	private $_CLASIFICACION_DOCUMENTO = null;
	private $_hasCLASIFICACION_DOCUMENTO = false;
	private $_FIRMA_DOCUMENTO = null;
	private $_hasFIRMA_DOCUMENTO = false;

	public function setNOMBRE_FICHERO($value)
	{
		$this->_NOMBRE_FICHERO = $value;
		$this->_hasNOMBRE_FICHERO = ($value !== null);
	}
	public function hasNOMBRE_FICHERO() {
		return $this->_hasNOMBRE_FICHERO;
	}
	public function getNOMBRE_FICHERO() {
		return $this->_NOMBRE_FICHERO;
	}

	public function setCODIGO_DOCUMENTO($value) {
		$this->_CODIGO_DOCUMENTO = $value;
		$this->_hasCODIGO_DOCUMENTO = ($value !== null);
	}
	public function hasCODIGO_DOCUMENTO() {
		return $this->_hasCODIGO_DOCUMENTO;
	}
	public function getCODIGO_DOCUMENTO() {
		return $this->_CODIGO_DOCUMENTO;
	}

	public function setDESCRIPCION_DOCUMENTO($value) {
		$this->_DESCRIPCION_DOCUMENTO = $value;
		$this->_hasDESCRIPCION_DOCUMENTO = ($value !== null);
	}
	public function hasDESCRIPCION_DOCUMENTO() {
		return $this->_hasDESCRIPCION_DOCUMENTO;
	}
	public function getDESCRIPCION_DOCUMENTO() {
		return $this->_DESCRIPCION_DOCUMENTO;
	}

	/**
	 * Establece el tipo de documento que se anexa entre [E, S, X, I, O, A, R, F, J, P, L N, C]
	 * Habituales: 	E: Entrada, S: Salida, X: Expediente, I: Documentos (en formato PDF), O: Otros
	 * Restringidos: A: Aviso de acuse, R: Registro del acuse, F: Oficio de remisin,
	 *	 	 	 	 J: Justificante, P: Justificante en formato PDF, L: Resolucin de la NT
					 N: Justificante de Alta NT, C: Justificante de No Comparecencia de la NT
	 * @param string $value
	 */
	public function setTIPO_DOCUMENTO($value) {
		$this->_TIPO_DOCUMENTO = $value;
		$this->_hasTIPO_DOCUMENTO = ($value !== null);
	}
	public function hasTIPO_DOCUMENTO() {
		return $this->_hasTIPO_DOCUMENTO;
	}
	public function getTIPO_DOCUMENTO() {
		return $this->_TIPO_DOCUMENTO;
	}



	public function setIDENTIFICADOR_FICHERO($value) {
		$this->_IDENTIFICADOR_FICHERO = $value;
		$this->_hasIDENTIFICADOR_FICHERO = ($value !== null);
	}
	public function hasIDENTIFICADOR_FICHERO() {
		return $this->_hasIDENTIFICADOR_FICHERO;
	}
	public function getIDENTIFICADOR_FICHERO() {
		return $this->_IDENTIFICADOR_FICHERO;
	}

	public function setHASH_DOCUMENTO($value) {
		$this->_HASH_DOCUMENTO = $value;
		$this->_hasHASH_DOCUMENTO = ($value !== null);
	}
	public function hasHASH_DOCUMENTO() {
		return $this->_hasHASH_DOCUMENTO;
	}
	public function getHASH_DOCUMENTO() {
		return $this->_HASH_DOCUMENTO;
	}

	public function setIDENTIFICADOR_DOCUMENTO_FIRMADO($value) {
		$this->_IDENTIFICADOR_DOCUMENTO_FIRMADO = $value;
		$this->_hasIDENTIFICADOR_DOCUMENTO_FIRMADO = ($value !== null);
	}
	public function hasIDENTIFICADOR_DOCUMENTO_FIRMADO() {
		return $this->_hasIDENTIFICADOR_DOCUMENTO_FIRMADO;
	}
	public function getIDENTIFICADOR_DOCUMENTO_FIRMADO() {
		return $this->_IDENTIFICADOR_DOCUMENTO_FIRMADO;
	}


	public function setCLASIFICACION_DOCUMENTO($value) {
		$this->_CLASIFICACION_DOCUMENTO = $value;
		$this->_hasCLASIFICACION_DOCUMENTO = ($value !== null);
	}
	public function hasCLASIFICACION_DOCUMENTO() {
		return $this->_hasCLASIFICACION_DOCUMENTO;
	}
	public function getCLASIFICACION_DOCUMENTO() {
		return $this->_CLASIFICACION_DOCUMENTO;
	}


	public function setFIRMA_DOCUMENTO($value) {
		$this->_FIRMA_DOCUMENTO = $value;
		$this->_hasFIRMA_DOCUMENTO = ($value !== null);
	}
	public function hasFIRMA_DOCUMENTO() {
		return $this->_hasFIRMA_DOCUMENTO;
	}
	public function getFIRMA_DOCUMENTO() {
		return $this->_FIRMA_DOCUMENTO;
	}


	public static function fromSoap($vData) {
		$newItem = new DOCUMENTOS_ANEXOS();
		if (!isset($vData['NOMBRE_FICHERO'])) {
			throw new \Exception('El parametro NOMBRE_FICHERO es obligatorio');
		}
		if (isset($vData['NOMBRE_FICHERO'])) {
			$newItem->setNOMBRE_FICHERO($vData['NOMBRE_FICHERO']);
		}
		if (isset($vData['CODIGO_DOCUMENTO'])) {
			$newItem->setCODIGO_DOCUMENTO($vData['CODIGO_DOCUMENTO']);
		}
		if (!isset($vData['DESCRIPCION_DOCUMENTO'])) {
			throw new \Exception('El parametro DESCRIPCION_DOCUMENTO es obligatorio');
		}
		if (isset($vData['DESCRIPCION_DOCUMENTO'])) {
			$newItem->setDESCRIPCION_DOCUMENTO($vData['DESCRIPCION_DOCUMENTO']);
		}
		if (!isset($vData['TIPO_DOCUMENTO'])) {
			throw new \Exception('El parametro TIPO_DOCUMENTO es obligatorio');
		}
		if (isset($vData['TIPO_DOCUMENTO'])) {
			$newItem->setTIPO_DOCUMENTO($vData['TIPO_DOCUMENTO']);
		}
		if (!isset($vData['IDENTIFICADOR_FICHERO'])) {
			throw new \Exception('El parametro IDENTIFICADOR_FICHERO es obligatorio');
		}
		if (isset($vData['IDENTIFICADOR_FICHERO'])) {
			$newItem->setIDENTIFICADOR_FICHERO($vData['IDENTIFICADOR_FICHERO']);
		}
		if (isset($vData['HASH_DOCUMENTO'])) {
			$newItem->setHASH_DOCUMENTO($vData['HASH_DOCUMENTO']);
		}
		if (isset($vData['IDENTIFICADOR_DOCUMENTO_FIRMADO'])) {
			$newItem->setIDENTIFICADOR_DOCUMENTO_FIRMADO($vData['IDENTIFICADOR_DOCUMENTO_FIRMADO']);
		}
		if (isset($vData['CLASIFICACION_DOCUMENTO'])) {
			$newItem->setCLASIFICACION_DOCUMENTO($vData['CLASIFICACION_DOCUMENTO']);
		}
		if (isset($vData['FIRMA_DOCUMENTO'])) {
			$newClass = FIRMA_DOCUMENTO::fromSoap($vData['FIRMA_DOCUMENTO']);
			$newItem->setFIRMA_DOCUMENTO($newClass);
		}

		return $newItem;
	}


	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_NOMBRE_FICHERO, 'NOMBRE_FICHERO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_CODIGO_DOCUMENTO, 'CODIGO_DOCUMENTO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_DESCRIPCION_DOCUMENTO, 'DESCRIPCION_DOCUMENTO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_TIPO_DOCUMENTO, 'TIPO_DOCUMENTO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_IDENTIFICADOR_FICHERO, 'IDENTIFICADOR_FICHERO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_HASH_DOCUMENTO, 'HASH_DOCUMENTO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_IDENTIFICADOR_DOCUMENTO_FIRMADO, 'IDENTIFICADOR_DOCUMENTO_FIRMADO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_CLASIFICACION_DOCUMENTO, 'CLASIFICACION_DOCUMENTO', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_FIRMA_DOCUMENTO, 'FIRMA_DOCUMENTO', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}


	public function generateString() {
		$str = '';

		if ($this->hasNOMBRE_FICHERO()) {
			$str .= '<NOMBRE_FICHERO>' . $this->getNOMBRE_FICHERO() . '</NOMBRE_FICHERO>';
		}
		if ($this->hasCODIGO_DOCUMENTO()) {
			$str .= '<CODIGO_DOCUMENTO>' . $this->getCODIGO_DOCUMENTO() . '</CODIGO_DOCUMENTO>';
		}
		if ($this->hasDESCRIPCION_DOCUMENTO()) {
			$str .= '<DESCRIPCION_DOCUMENTO>' . $this->getDESCRIPCION_DOCUMENTO() . '</DESCRIPCION_DOCUMENTO>';
		}
		if ($this->hasTIPO_DOCUMENTO()) {
			$str .= '<TIPO_DOCUMENTO>' . $this->getTIPO_DOCUMENTO() . '</TIPO_DOCUMENTO>';
		}
		if ($this->hasIDENTIFICADOR_FICHERO()) {
			$str .= '<IDENTIFICADOR_FICHERO>' . $this->getIDENTIFICADOR_FICHERO() . '</IDENTIFICADOR_FICHERO>';
		}
		if ($this->hasHASH_DOCUMENTO()) {
			$str .= '<HASH_DOCUMENTO>' . $this->getHASH_DOCUMENTO() . '</HASH_DOCUMENTO>';
		}
		if ($this->hasIDENTIFICADOR_DOCUMENTO_FIRMADO()) {
			$str .= '<IDENTIFICADOR_DOCUMENTO_FIRMADO>' . $this->getIDENTIFICADOR_DOCUMENTO_FIRMADO() . '</IDENTIFICADOR_DOCUMENTO_FIRMADO>';
		}
		if ($this->hasCLASIFICACION_DOCUMENTO()) {
			$str .= '<CLASIFICACION_DOCUMENTO>' . $this->getCLASIFICACION_DOCUMENTO() . '</CLASIFICACION_DOCUMENTO>';
		}
		if ($this->hasFIRMA_DOCUMENTO()) {
			$str .= '<FIRMA_DOCUMENTO>' . $this->getFIRMA_DOCUMENTO()->generateString() . '</FIRMA_DOCUMENTO>';
		}

		return $str;
	}


	public static function fromDOM($nodeParent) {
		$newItem = new DOCUMENTOS_ANEXOS();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'NOMBRE_FICHERO') {
				$newItem->setNOMBRE_FICHERO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CODIGO_DOCUMENTO') {
				$newItem->setCODIGO_DOCUMENTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'DESCRIPCION_DOCUMENTO') {
				$newItem->setDESCRIPCION_DOCUMENTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'TIPO_DOCUMENTO') {
				$newItem->setTIPO_DOCUMENTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'IDENTIFICADOR_FICHERO') {
				$newItem->setIDENTIFICADOR_FICHERO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'HASH_DOCUMENTO') {
				$newItem->setHASH_DOCUMENTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'IDENTIFICADOR_DOCUMENTO_FIRMADO') {
				$newItem->setIDENTIFICADOR_DOCUMENTO_FIRMADO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CLASIFICACION_DOCUMENTO') {
				$newItem->setCLASIFICACION_DOCUMENTO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FIRMA_DOCUMENTO') {
				$newClass = FIRMA_DOCUMENTO::fromDOM($nodeXML);
				$newItem->setFIRMA_DOCUMENTO($newClass);
			}

		}
		return $newItem;
	}
}//Fin clase

class DATOS_DEL_REGISTRO extends SoapObject
{
	private $_DATOS_LIBRO_REGISTRAL = null;
	private $_hasDATOS_LIBRO_REGISTRAL = false;
	private $_DATOS_UNIDAD = null;
	private $_hasDATOS_UNIDAD = false;
	private $_DATOS_INTERESADO = array();
	private $_hasDATOS_INTERESADO = false;
	private $_OTROS_DATOS = null;
	private $_hasOTROS_DATOS = false;
	private $_DATOS_EXPEDIENTES = null;
	private $_hasDATOS_EXPEDIENTES = false;
	private $_DOCUMENTOS_ANEXOS = array();
	private $_hasDOCUMENTOS_ANEXOS = false;


	public function setDATOS_LIBRO_REGISTRAL($value) {
		$this->_DATOS_LIBRO_REGISTRAL = $value;
		$this->_hasDATOS_LIBRO_REGISTRAL = ($value !== null);
	}
	public function hasDATOS_LIBRO_REGISTRAL() {
		return $this->_hasDATOS_LIBRO_REGISTRAL;
	}
	public function getDATOS_LIBRO_REGISTRAL() {
		return $this->_DATOS_LIBRO_REGISTRAL;
	}

	public function setDATOS_UNIDAD($value) {
		$this->_DATOS_UNIDAD = $value;
		$this->_hasDATOS_UNIDAD = ($value !== null);
	}
	public function hasDATOS_UNIDAD() {
		return $this->_hasDATOS_UNIDAD;
	}
	public function getDATOS_UNIDAD() {
		return $this->_DATOS_UNIDAD;
	}

	public function replaceArrayDATOS_INTERESADO($value) {
		$this->_DATOS_INTERESADO = $value;
		$this->_hasDATOS_INTERESADO = (isset($this->_DATOS_INTERESADO) && !empty($this->_DATOS_INTERESADO));
	}
	public function retrieveArrayDATOS_INTERESADO() {
		return $this->_DATOS_INTERESADO;
	}
	public function addDATOS_INTERESADO($value) {
		array_push($this->_DATOS_INTERESADO, $value);
		$this->_hasDATOS_INTERESADO = (isset($this->_DATOS_INTERESADO) && !empty($this->_DATOS_INTERESADO));
	}
	public function hasDATOS_INTERESADO() {
		return $this->_hasDATOS_INTERESADO;
	}
	public function getDATOS_INTERESADO($index) {
		return $this->_DATOS_INTERESADO[$index];
	}
	public function countDATOS_INTERESADO() {
		return count($this->_DATOS_INTERESADO);
	}

	public function setOTROS_DATOS($value) {
		$this->_OTROS_DATOS = $value;
		$this->_hasOTROS_DATOS = ($value !== null);
	}
	public function hasOTROS_DATOS() {
		return $this->_hasOTROS_DATOS;
	}
	public function getOTROS_DATOS() {
		return $this->_OTROS_DATOS;
	}

	public function setDATOS_EXPEDIENTES($value) {
		$this->_DATOS_EXPEDIENTES = $value;
		$this->_hasDATOS_EXPEDIENTES = ($value !== null);
	}
	public function hasDATOS_EXPEDIENTES() {
		return $this->_hasDATOS_EXPEDIENTES;
	}
	public function getDATOS_EXPEDIENTES() {
		return $this->_DATOS_EXPEDIENTES;
	}

	public function replaceArrayDOCUMENTOS_ANEXOS($value) {
		$this->_DOCUMENTOS_ANEXOS = $value;
		$this->_hasDOCUMENTOS_ANEXOS = (isset($this->_DOCUMENTOS_ANEXOS) && !empty($this->_DOCUMENTOS_ANEXOS));
	}
	public function retrieveArrayDOCUMENTOS_ANEXOS() {
		return $this->_DOCUMENTOS_ANEXOS;
	}
	public function addDOCUMENTOS_ANEXOS($value) {
		array_push($this->_DOCUMENTOS_ANEXOS, $value);
		$this->_hasDOCUMENTOS_ANEXOS = (isset($this->_DOCUMENTOS_ANEXOS) && !empty($this->_DOCUMENTOS_ANEXOS));
	}
	public function hasDOCUMENTOS_ANEXOS() {
		return $this->_hasDOCUMENTOS_ANEXOS;
	}
	public function getDOCUMENTOS_ANEXOS($index) {
		return $this->_DOCUMENTOS_ANEXOS[$index];
	}
	public function countDOCUMENTOS_ANEXOS() {
		return count($this->_DOCUMENTOS_ANEXOS);
	}


	public static function fromSoap($vData) {
		$newItem = new DATOS_DEL_REGISTRO();
		if (!isset($vData['DATOS_LIBRO_REGISTRAL'])) {
			throw new \Exception('El parametro DATOS_LIBRO_REGISTRAL es obligatorio');
		}
		if (isset($vData['DATOS_LIBRO_REGISTRAL'])) {
			$newClass = DATOS_LIBRO_REGISTRAL::fromSoap($vData['DATOS_LIBRO_REGISTRAL']);
			$newItem->setDATOS_LIBRO_REGISTRAL($newClass);
		}
		if (!isset($vData['DATOS_UNIDAD'])) {
			throw new \Exception('El parametro DATOS_UNIDAD es obligatorio');
		}
		if (isset($vData['DATOS_UNIDAD'])) {
			$newClass = DATOS_UNIDAD::fromSoap($vData['DATOS_UNIDAD']);
			$newItem->setDATOS_UNIDAD($newClass);
		}
		if (!isset($vData['DATOS_INTERESADO'])) {
			throw new \Exception('El parametro DATOS_INTERESADO es obligatorio');
		}
		if (isset($vData['DATOS_INTERESADO']) && !empty($vData['DATOS_INTERESADO'])) {
			if (SoapObject::is_assoc($vData['DATOS_INTERESADO'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DATOS_INTERESADO::fromSoap($vData['DATOS_INTERESADO']);
				$newItem->addDATOS_INTERESADO($newClass);
			} else {
				foreach ($vData['DATOS_INTERESADO'] as $oVar) {
					$newClass = DATOS_INTERESADO::fromSoap($oVar);
					$newItem->addDATOS_INTERESADO($newClass);
				}
			}
		}
		if (!isset($vData['OTROS_DATOS'])) {
			throw new \Exception('El parametro OTROS_DATOS es obligatorio');
		}
		if (isset($vData['OTROS_DATOS'])) {
			$newClass = OTROS_DATOS::fromSoap($vData['OTROS_DATOS']);
			$newItem->setOTROS_DATOS($newClass);
		}
		if (!isset($vData['DATOS_EXPEDIENTES'])) {
			throw new \Exception('El parametro DATOS_EXPEDIENTES es obligatorio');
		}
		if (isset($vData['DATOS_EXPEDIENTES'])) {
			$newClass = DATOS_EXPEDIENTES::fromSoap($vData['DATOS_EXPEDIENTES']);
			$newItem->setDATOS_EXPEDIENTES($newClass);
		}
		if (!isset($vData['DOCUMENTOS_ANEXOS'])) {
			throw new \Exception('El parametro DOCUMENTOS_ANEXOS es obligatorio');
		}
		if (isset($vData['DOCUMENTOS_ANEXOS']) && !empty($vData['DOCUMENTOS_ANEXOS'])) {
			if (SoapObject::is_assoc($vData['DOCUMENTOS_ANEXOS'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = DOCUMENTOS_ANEXOS::fromSoap($vData['DOCUMENTOS_ANEXOS']);
				$newItem->addDOCUMENTOS_ANEXOS($newClass);
			} else {
				foreach ($vData['DOCUMENTOS_ANEXOS'] as $oVar) {
					$newClass = DOCUMENTOS_ANEXOS::fromSoap($oVar);
					$newItem->addDOCUMENTOS_ANEXOS($newClass);
				}
			}
		}

		return $newItem;
	}

	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_DATOS_LIBRO_REGISTRAL, 'DATOS_LIBRO_REGISTRAL', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_DATOS_UNIDAD, 'DATOS_UNIDAD', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_DATOS_INTERESADO, 'DATOS_INTERESADO', SOAP_ENC_OBJECT, $namespace, 1, unbounded);
		$this->__doChild($myLevel, $this->_OTROS_DATOS, 'OTROS_DATOS', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_DATOS_EXPEDIENTES, 'DATOS_EXPEDIENTES', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_DOCUMENTOS_ANEXOS, 'DOCUMENTOS_ANEXOS', SOAP_ENC_OBJECT, $namespace, 1, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}

	public function generateString() {
		$str = '';

		if ($this->hasDATOS_LIBRO_REGISTRAL()) {
			$str .= '<DATOS_LIBRO_REGISTRAL>' . $this->getDATOS_LIBRO_REGISTRAL()->generateString() . '</DATOS_LIBRO_REGISTRAL>';
		}
		if ($this->hasDATOS_UNIDAD()) {
			$str .= '<DATOS_UNIDAD>' . $this->getDATOS_UNIDAD()->generateString() . '</DATOS_UNIDAD>';
		}
		if ($this->hasDATOS_INTERESADO()) {
			for ($iPos=0; $iPos<$this->countDATOS_INTERESADO(); $iPos++) {
				$str .= '<DATOS_INTERESADO>' . $this->getDATOS_INTERESADO($iPos)->generateString() . '</DATOS_INTERESADO>';
			}
		}
		if ($this->hasOTROS_DATOS()) {
			$str .= '<OTROS_DATOS>' . $this->getOTROS_DATOS()->generateString() . '</OTROS_DATOS>';
		}
		if ($this->hasDATOS_EXPEDIENTES()) {
			$str .= '<DATOS_EXPEDIENTES>' . $this->getDATOS_EXPEDIENTES()->generateString() . '</DATOS_EXPEDIENTES>';
		}
		if ($this->hasDOCUMENTOS_ANEXOS()) {
			for ($iPos=0; $iPos<$this->countDOCUMENTOS_ANEXOS(); $iPos++) {
				$str .= '<DOCUMENTOS_ANEXOS>' . $this->getDOCUMENTOS_ANEXOS($iPos)->generateString() . '</DOCUMENTOS_ANEXOS>';
			}
		}

		return $str;
	}

	public static function fromDOM($nodeParent) {
		$newItem = new DATOS_DEL_REGISTRO();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'DATOS_LIBRO_REGISTRAL') {
				$newClass = DATOS_LIBRO_REGISTRAL::fromDOM($nodeXML);
				$newItem->setDATOS_LIBRO_REGISTRAL($newClass);
			}
			if ($nodeXML->nodeName == 'DATOS_UNIDAD') {
				$newClass = DATOS_UNIDAD::fromDOM($nodeXML);
				$newItem->setDATOS_UNIDAD($newClass);
			}
			if ($nodeXML->nodeName == 'DATOS_INTERESADO') {
				$newClass = DATOS_INTERESADO::fromDOM($nodeXML);
				$newItem->addDATOS_INTERESADO($newClass);
			}
			if ($nodeXML->nodeName == 'OTROS_DATOS') {
				$newClass = OTROS_DATOS::fromDOM($nodeXML);
				$newItem->setOTROS_DATOS($newClass);
			}
			if ($nodeXML->nodeName == 'DATOS_EXPEDIENTES') {
				$newClass = DATOS_EXPEDIENTES::fromDOM($nodeXML);
				$newItem->setDATOS_EXPEDIENTES($newClass);
			}
			if ($nodeXML->nodeName == 'DOCUMENTOS_ANEXOS') {
				$newClass = DOCUMENTOS_ANEXOS::fromDOM($nodeXML);
				$newItem->addDOCUMENTOS_ANEXOS($newClass);
			}

		}
		return $newItem;
	}
}//Fin clase

class FIRMA_DATOS_DEL_REGISTRO extends SoapObject {
	// name="ENTIDAD_CERTIFICADORA" type="TypeENTIDAD_CERTIFICADORA"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_ENTIDAD_CERTIFICADORA = null;
	private $_hasENTIDAD_CERTIFICADORA = false;
	public function setENTIDAD_CERTIFICADORA($value) {
		$this->_ENTIDAD_CERTIFICADORA = $value;
		$this->_hasENTIDAD_CERTIFICADORA = ($value !== null);
	}
	public function hasENTIDAD_CERTIFICADORA() {
		return $this->_hasENTIDAD_CERTIFICADORA;
	}
	public function getENTIDAD_CERTIFICADORA() {
		return $this->_ENTIDAD_CERTIFICADORA;
	}

	// name="FORMATO_FIRMA" type="TypeFORMATO_FIRMA"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_FORMATO_FIRMA = null;
	private $_hasFORMATO_FIRMA = false;
	public function setFORMATO_FIRMA($value) {
		$this->_FORMATO_FIRMA = $value;
		$this->_hasFORMATO_FIRMA = ($value !== null);
	}
	public function hasFORMATO_FIRMA() {
		return $this->_hasFORMATO_FIRMA;
	}
	public function getFORMATO_FIRMA() {
		return $this->_FORMATO_FIRMA;
	}

	// name="VALOR_FIRMA" type="xs:string"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_VALOR_FIRMA = null;
	private $_hasVALOR_FIRMA = false;
	public function setVALOR_FIRMA($value) {
		$this->_VALOR_FIRMA = $value;
		$this->_hasVALOR_FIRMA = ($value !== null);
	}
	public function hasVALOR_FIRMA() {
		return $this->_hasVALOR_FIRMA;
	}
	public function getVALOR_FIRMA() {
		return $this->_VALOR_FIRMA;
	}


	public static function fromSoap($vData) {
		$newItem = new FIRMA_DATOS_DEL_REGISTRO();
		if (!isset($vData['ENTIDAD_CERTIFICADORA'])) {
			throw new \Exception('El parametro ENTIDAD_CERTIFICADORA es obligatorio');
		}
		if (isset($vData['ENTIDAD_CERTIFICADORA'])) {
			$newItem->setENTIDAD_CERTIFICADORA($vData['ENTIDAD_CERTIFICADORA']);
		}
		if (!isset($vData['FORMATO_FIRMA'])) {
			throw new \Exception('El parametro FORMATO_FIRMA es obligatorio');
		}
		if (isset($vData['FORMATO_FIRMA'])) {
			$newItem->setFORMATO_FIRMA($vData['FORMATO_FIRMA']);
		}
		if (!isset($vData['VALOR_FIRMA'])) {
			throw new \Exception('El parametro VALOR_FIRMA es obligatorio');
		}
		if (isset($vData['VALOR_FIRMA'])) {
			$newItem->setVALOR_FIRMA($vData['VALOR_FIRMA']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_ENTIDAD_CERTIFICADORA, 'ENTIDAD_CERTIFICADORA', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_FORMATO_FIRMA, 'FORMATO_FIRMA', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_VALOR_FIRMA, 'VALOR_FIRMA', 101, $namespace, 1, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasENTIDAD_CERTIFICADORA()) {
			$str .= '<ENTIDAD_CERTIFICADORA>' . $this->getENTIDAD_CERTIFICADORA() . '</ENTIDAD_CERTIFICADORA>';
		}
		if ($this->hasFORMATO_FIRMA()) {
			$str .= '<FORMATO_FIRMA>' . $this->getFORMATO_FIRMA() . '</FORMATO_FIRMA>';
		}
		if ($this->hasVALOR_FIRMA()) {
			$str .= '<VALOR_FIRMA>' . $this->getVALOR_FIRMA() . '</VALOR_FIRMA>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new FIRMA_DATOS_DEL_REGISTRO();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'ENTIDAD_CERTIFICADORA') {
				$newItem->setENTIDAD_CERTIFICADORA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FORMATO_FIRMA') {
				$newItem->setFORMATO_FIRMA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'VALOR_FIRMA') {
				$newItem->setVALOR_FIRMA($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}

class JUSTIFICANTE extends SoapObject
{
	private $_NUMERO_REGISTRO = null;
	private $_hasNUMERO_REGISTRO = false;
	private $_FECHA_REGISTRO = null;
	private $_hasFECHA_REGISTRO = false;
	private $_EXPEDIENTE = null;
	private $_hasEXPEDIENTE = false;
	private $_CLAVE_CONSULTA = null;
	private $_hasCLAVE_CONSULTA = false;


	public function setNUMERO_REGISTRO($value) {
		$this->_NUMERO_REGISTRO = $value;
		$this->_hasNUMERO_REGISTRO = ($value !== null);
	}
	public function hasNUMERO_REGISTRO() {
		return $this->_hasNUMERO_REGISTRO;
	}
	public function getNUMERO_REGISTRO() {
		return $this->_NUMERO_REGISTRO;
	}

	public function setFECHA_REGISTRO($value) {
		$this->_FECHA_REGISTRO = $value;
		$this->_hasFECHA_REGISTRO = ($value !== null);
	}
	public function hasFECHA_REGISTRO() {
		return $this->_hasFECHA_REGISTRO;
	}
	public function getFECHA_REGISTRO() {
		return $this->_FECHA_REGISTRO;
	}

	public function setEXPEDIENTE($value) {
		$this->_EXPEDIENTE = $value;
		$this->_hasEXPEDIENTE = ($value !== null);
	}
	public function hasEXPEDIENTE() {
		return $this->_hasEXPEDIENTE;
	}
	public function getEXPEDIENTE() {
		return $this->_EXPEDIENTE;
	}

	public function setCLAVE_CONSULTA($value) {
		$this->_CLAVE_CONSULTA = $value;
		$this->_hasCLAVE_CONSULTA = ($value !== null);
	}
	public function hasCLAVE_CONSULTA() {
		return $this->_hasCLAVE_CONSULTA;
	}
	public function getCLAVE_CONSULTA() {
		return $this->_CLAVE_CONSULTA;
	}


	public static function fromSoap($vData) {
		$newItem = new JUSTIFICANTE();
		if (!isset($vData['NUMERO_REGISTRO'])) {
			throw new \Exception('El parametro NUMERO_REGISTRO es obligatorio');
		}
		if (isset($vData['NUMERO_REGISTRO'])) {
			$newItem->setNUMERO_REGISTRO($vData['NUMERO_REGISTRO']);
		}
		if (!isset($vData['FECHA_REGISTRO'])) {
			throw new \Exception('El parametro FECHA_REGISTRO es obligatorio');
		}
		if (isset($vData['FECHA_REGISTRO'])) {
			$newItem->setFECHA_REGISTRO($vData['FECHA_REGISTRO']);
		}
		if (isset($vData['EXPEDIENTE'])) {
			$newItem->setEXPEDIENTE($vData['EXPEDIENTE']);
		}
		if (!isset($vData['CLAVE_CONSULTA'])) {
			throw new \Exception('El parametro CLAVE_CONSULTA es obligatorio');
		}
		if (isset($vData['CLAVE_CONSULTA'])) {
			$newItem->setCLAVE_CONSULTA($vData['CLAVE_CONSULTA']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_NUMERO_REGISTRO, 'NUMERO_REGISTRO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_FECHA_REGISTRO, 'FECHA_REGISTRO', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_EXPEDIENTE, 'EXPEDIENTE', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_CLAVE_CONSULTA, 'CLAVE_CONSULTA', 101, $namespace, 1, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasNUMERO_REGISTRO()) {
			$str .= '<NUMERO_REGISTRO>' . $this->getNUMERO_REGISTRO() . '</NUMERO_REGISTRO>';
		}
		if ($this->hasFECHA_REGISTRO()) {
			$str .= '<FECHA_REGISTRO>' . $this->getFECHA_REGISTRO() . '</FECHA_REGISTRO>';
		}
		if ($this->hasEXPEDIENTE()) {
			$str .= '<EXPEDIENTE>' . $this->getEXPEDIENTE() . '</EXPEDIENTE>';
		}
		if ($this->hasCLAVE_CONSULTA()) {
			$str .= '<CLAVE_CONSULTA>' . $this->getCLAVE_CONSULTA() . '</CLAVE_CONSULTA>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new JUSTIFICANTE();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'NUMERO_REGISTRO') {
				$newItem->setNUMERO_REGISTRO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FECHA_REGISTRO') {
				$newItem->setFECHA_REGISTRO($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'EXPEDIENTE') {
				$newItem->setEXPEDIENTE($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'CLAVE_CONSULTA') {
				$newItem->setCLAVE_CONSULTA($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}

class FIRMA_JUSTIFICANTE extends SoapObject
{
	private $_ENTIDAD_CERTIFICADORA = null;
	private $_hasENTIDAD_CERTIFICADORA = false;
	private $_FORMATO_FIRMA = null;
	private $_hasFORMATO_FIRMA = false;
	private $_VALOR_FIRMA = null;
	private $_hasVALOR_FIRMA = false;

	public function setENTIDAD_CERTIFICADORA($value) {
		$this->_ENTIDAD_CERTIFICADORA = $value;
		$this->_hasENTIDAD_CERTIFICADORA = ($value !== null);
	}
	public function hasENTIDAD_CERTIFICADORA() {
		return $this->_hasENTIDAD_CERTIFICADORA;
	}
	public function getENTIDAD_CERTIFICADORA() {
		return $this->_ENTIDAD_CERTIFICADORA;
	}


	public function setFORMATO_FIRMA($value) {
		$this->_FORMATO_FIRMA = $value;
		$this->_hasFORMATO_FIRMA = ($value !== null);
	}
	public function hasFORMATO_FIRMA() {
		return $this->_hasFORMATO_FIRMA;
	}
	public function getFORMATO_FIRMA() {
		return $this->_FORMATO_FIRMA;
	}

	public function setVALOR_FIRMA($value) {
		$this->_VALOR_FIRMA = $value;
		$this->_hasVALOR_FIRMA = ($value !== null);
	}
	public function hasVALOR_FIRMA() {
		return $this->_hasVALOR_FIRMA;
	}
	public function getVALOR_FIRMA() {
		return $this->_VALOR_FIRMA;
	}


	public static function fromSoap($vData) {
		$newItem = new FIRMA_JUSTIFICANTE();
		if (!isset($vData['ENTIDAD_CERTIFICADORA'])) {
			throw new \Exception('El parametro ENTIDAD_CERTIFICADORA es obligatorio');
		}
		if (isset($vData['ENTIDAD_CERTIFICADORA'])) {
			$newItem->setENTIDAD_CERTIFICADORA($vData['ENTIDAD_CERTIFICADORA']);
		}
		if (!isset($vData['FORMATO_FIRMA'])) {
			throw new \Exception('El parametro FORMATO_FIRMA es obligatorio');
		}
		if (isset($vData['FORMATO_FIRMA'])) {
			$newItem->setFORMATO_FIRMA($vData['FORMATO_FIRMA']);
		}
		if (!isset($vData['VALOR_FIRMA'])) {
			throw new \Exception('El parametro VALOR_FIRMA es obligatorio');
		}
		if (isset($vData['VALOR_FIRMA'])) {
			$newItem->setVALOR_FIRMA($vData['VALOR_FIRMA']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_ENTIDAD_CERTIFICADORA, 'ENTIDAD_CERTIFICADORA', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_FORMATO_FIRMA, 'FORMATO_FIRMA', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_VALOR_FIRMA, 'VALOR_FIRMA', 101, $namespace, 1, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
	public function generateString() {
		$str = '';

		if ($this->hasENTIDAD_CERTIFICADORA()) {
			$str .= '<ENTIDAD_CERTIFICADORA>' . $this->getENTIDAD_CERTIFICADORA() . '</ENTIDAD_CERTIFICADORA>';
		}
		if ($this->hasFORMATO_FIRMA()) {
			$str .= '<FORMATO_FIRMA>' . $this->getFORMATO_FIRMA() . '</FORMATO_FIRMA>';
		}
		if ($this->hasVALOR_FIRMA()) {
			$str .= '<VALOR_FIRMA>' . $this->getVALOR_FIRMA() . '</VALOR_FIRMA>';
		}

		return $str;
	}
	public static function fromDOM($nodeParent) {
		$newItem = new FIRMA_JUSTIFICANTE();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'ENTIDAD_CERTIFICADORA') {
				$newItem->setENTIDAD_CERTIFICADORA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'FORMATO_FIRMA') {
				$newItem->setFORMATO_FIRMA($nodeXML->nodeValue);
			}
			if ($nodeXML->nodeName == 'VALOR_FIRMA') {
				$newItem->setVALOR_FIRMA($nodeXML->nodeValue);
			}

		}
		return $newItem;
	}
}//Fin clase FIRMA_JUSTIFICANTE

class API_CREAREGISTRO extends SoapObject
{
	private $_DATOS_DEL_REGISTRO = null;
	private $_hasDATOS_DEL_REGISTRO = false;
	private $_FIRMA_DATOS_DEL_REGISTRO = null;
	private $_hasFIRMA_DATOS_DEL_REGISTRO = false;
	private $_JUSTIFICANTE = null;
	private $_hasJUSTIFICANTE = false;
	private $_FIRMA_JUSTIFICANTE = null;
	private $_hasFIRMA_JUSTIFICANTE = false;


	public function setDATOS_DEL_REGISTRO($value) {
		$this->_DATOS_DEL_REGISTRO = $value;
		$this->_hasDATOS_DEL_REGISTRO = ($value !== null);
	}
	public function hasDATOS_DEL_REGISTRO() {
		return $this->_hasDATOS_DEL_REGISTRO;
	}
	public function getDATOS_DEL_REGISTRO() {
		return $this->_DATOS_DEL_REGISTRO;
	}

	public function setFIRMA_DATOS_DEL_REGISTRO($value) {
		$this->_FIRMA_DATOS_DEL_REGISTRO = $value;
		$this->_hasFIRMA_DATOS_DEL_REGISTRO = ($value !== null);
	}
	public function hasFIRMA_DATOS_DEL_REGISTRO() {
		return $this->_hasFIRMA_DATOS_DEL_REGISTRO;
	}
	public function getFIRMA_DATOS_DEL_REGISTRO() {
		return $this->_FIRMA_DATOS_DEL_REGISTRO;
	}

	public function setJUSTIFICANTE($value) {
		$this->_JUSTIFICANTE = $value;
		$this->_hasJUSTIFICANTE = ($value !== null);
	}
	public function hasJUSTIFICANTE() {
		return $this->_hasJUSTIFICANTE;
	}
	public function getJUSTIFICANTE() {
		return $this->_JUSTIFICANTE;
	}

	public function setFIRMA_JUSTIFICANTE($value) {
		$this->_FIRMA_JUSTIFICANTE = $value;
		$this->_hasFIRMA_JUSTIFICANTE = ($value !== null);
	}
	public function hasFIRMA_JUSTIFICANTE() {
		return $this->_hasFIRMA_JUSTIFICANTE;
	}
	public function getFIRMA_JUSTIFICANTE() {
		return $this->_FIRMA_JUSTIFICANTE;
	}


	public static function fromSoap($vData)
	{
		$newItem = new API_CREAREGISTRO();
		if (!isset($vData['DATOS_DEL_REGISTRO'])) {
			throw new \Exception('El parametro DATOS_DEL_REGISTRO es obligatorio');
		}
		if (isset($vData['DATOS_DEL_REGISTRO'])) {
			$newClass = DATOS_DEL_REGISTRO::fromSoap($vData['DATOS_DEL_REGISTRO']);
			$newItem->setDATOS_DEL_REGISTRO($newClass);
		}
		if (isset($vData['FIRMA_DATOS_DEL_REGISTRO'])) {
			$newClass = FIRMA_DATOS_DEL_REGISTRO::fromSoap($vData['FIRMA_DATOS_DEL_REGISTRO']);
			$newItem->setFIRMA_DATOS_DEL_REGISTRO($newClass);
		}
		if (isset($vData['JUSTIFICANTE'])) {
			$newClass = JUSTIFICANTE::fromSoap($vData['JUSTIFICANTE']);
			$newItem->setJUSTIFICANTE($newClass);
		}
		if (isset($vData['FIRMA_JUSTIFICANTE'])) {
			$newClass = FIRMA_JUSTIFICANTE::fromSoap($vData['FIRMA_JUSTIFICANTE']);
			$newItem->setFIRMA_JUSTIFICANTE($newClass);
		}

		return $newItem;
	}


	public function toSoap($fieldName, $namespace)
	{
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_DATOS_DEL_REGISTRO, 'DATOS_DEL_REGISTRO', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_FIRMA_DATOS_DEL_REGISTRO, 'FIRMA_DATOS_DEL_REGISTRO', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_JUSTIFICANTE, 'JUSTIFICANTE', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_FIRMA_JUSTIFICANTE, 'FIRMA_JUSTIFICANTE', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}


	public function generateString() {
		$str = '';

		if ($this->hasDATOS_DEL_REGISTRO()) {
			$str .= '<DATOS_DEL_REGISTRO>' . $this->getDATOS_DEL_REGISTRO()->generateString() . '</DATOS_DEL_REGISTRO>';
		}
		if ($this->hasFIRMA_DATOS_DEL_REGISTRO()) {
			$str .= '<FIRMA_DATOS_DEL_REGISTRO>' . $this->getFIRMA_DATOS_DEL_REGISTRO()->generateString() . '</FIRMA_DATOS_DEL_REGISTRO>';
		}
		if ($this->hasJUSTIFICANTE()) {
			$str .= '<JUSTIFICANTE>' . $this->getJUSTIFICANTE()->generateString() . '</JUSTIFICANTE>';
		}
		if ($this->hasFIRMA_JUSTIFICANTE()) {
			$str .= '<FIRMA_JUSTIFICANTE>' . $this->getFIRMA_JUSTIFICANTE()->generateString() . '</FIRMA_JUSTIFICANTE>';
		}

		return $str;
	}


	public static function fromDOM($nodeParent) {
		$newItem = new API_CREAREGISTRO();
		foreach ($nodeParent->childNodes as $nodeXML) {
			if ($nodeXML->nodeName == 'DATOS_DEL_REGISTRO') {
				$newClass = DATOS_DEL_REGISTRO::fromDOM($nodeXML);
				$newItem->setDATOS_DEL_REGISTRO($newClass);
			}
			if ($nodeXML->nodeName == 'FIRMA_DATOS_DEL_REGISTRO') {
				$newClass = FIRMA_DATOS_DEL_REGISTRO::fromDOM($nodeXML);
				$newItem->setFIRMA_DATOS_DEL_REGISTRO($newClass);
			}
			if ($nodeXML->nodeName == 'JUSTIFICANTE') {
				$newClass = JUSTIFICANTE::fromDOM($nodeXML);
				$newItem->setJUSTIFICANTE($newClass);
			}
			if ($nodeXML->nodeName == 'FIRMA_JUSTIFICANTE') {
				$newClass = FIRMA_JUSTIFICANTE::fromDOM($nodeXML);
				$newItem->setFIRMA_JUSTIFICANTE($newClass);
			}

		}
		return $newItem;
	}
}
?>